import React, { useState, useEffect } from 'react';
import ReactDOM from 'react-dom';
import {
  csv,
  scaleBand,
  scaleLinear,
  max,
  axisBottom,
  axisLeft,
} from 'd3';

const csvUrl =
  'https://gist.githubusercontent.com/akhilcharugulla/56150d0d98677cf8b511530e34f71a77/raw/10f08ee3dbf2b355a5b7aa408143fbc410b75571/cars_cleaned.csv';
const height = 500;
const width = 960;
const margin = {
  top: 20,
  right: 20,
  bottom: 70,
  left: 100,
};

const App = () => {
  const [data, setData] = useState(null);

  useEffect(() => {
    const row = (d) => {
      d.Price = +d.Price;
      return d;
    };

    csv(csvUrl, row).then((data) => {
      setData(data);
    });
  }, []);

  if (!data) {
    return <pre>Loading...</pre>;
  }

  const innerHeight = height - margin.top - margin.bottom;
  const innerWidth = width - margin.left - margin.right;

  const aggregatedData = data.reduce((acc, curr) => {
    acc[curr.Type] = (acc[curr.Type] || 0) + curr.Price;
    return acc;
  }, {});

  const types = Object.keys(aggregatedData);

  const yScale = scaleBand()
    .domain(types)
    .range([0, innerHeight])
    .padding(0.1);

  const xScale = scaleLinear()
    .domain([0, max(Object.values(aggregatedData))])
    .range([0, innerWidth]);

  return (
    <svg width={width} height={height}>
      <g
        transform={`translate(${margin.left},${margin.top})`}
      >
        {types.map((type, index) => (
          <rect
            key={type}
            x={0}
            y={yScale(type)}
            width={xScale(aggregatedData[type])}
            height={yScale.bandwidth()}
            fill={`#2ca02c`}
          />
        ))}
        <g
          transform={`translate(0,${innerHeight})`}
          ref={(node) =>
            axisBottom(xScale)(d3.select(node))
          }
        />
        <g
          ref={(node) => axisLeft(yScale)(d3.select(node))}
        />
      </g>
      {/* Price label */}
      <text
        x={margin.left + innerWidth / 2} // Positioned at the middle of the inner width
        y={height - margin.bottom / 3} // Adjusted for spacing
        textAnchor="middle"
        fontSize="16"
      >
        Average Price
      </text>
      {/* Car Type label */}
      <text
        x={margin.left - 30} // Adjusted for positioning away from y-axis
        y={height / 2} // Placed in the middle of y-axis
        transform={`rotate(-90, ${margin.left - 60}, ${height / 2})`} // Rotate by 90 degrees
        textAnchor="end" // Adjusted for alignment
        fontSize="18"
      >
        Vehicle Type
      </text>
    </svg>
  );
};

const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
